==> qmmp-plugin-pack-0.10.3.tar.bz2: qmmp-plugin-pack-0.10.3/src/Input/xmp/translations/xmp_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="53"/>
        <source>XMP Plugin</source>
        <translation>Plugin XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="67"/>
        <source>Module Files</source>
        <translation>Ficheiros de modulación</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="122"/>
        <source>About XMP Audio Plugin</source>
        <translation>Acerca do plugin XMP Audio</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="123"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Plugin Qmmp XMP Audio</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="124"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="125"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Compilando con libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Preferencias do plugin XMP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation>Factor de amplificación:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Mestura Estéreo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Tipo de interpolación:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Filtro de efecto de paso baixo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Utilizar sincronización vblank</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Emular erro do Protracker 2.x FX9</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>Veciño máis próximo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>Interpolación cúbica</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="49"/>
        <source>File name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Volume scale</source>
        <translation>Escala do volume</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of patterns</source>
        <translation>Número de patróns</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of tracks</source>
        <translation>Número de pistas</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Tracks per pattern</source>
        <translation>Pistas por patrón</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Number of instruments</source>
        <translation>Número de instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Number of samples</source>
        <translation>Número de mostras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Initial speed</source>
        <translation>Velocidade inicial</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="62"/>
        <source>Initial BPM</source>
        <translation>BPM iniciais</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="63"/>
        <source>Module length in patterns</source>
        <translation>Lonxitude do módulo en patróns</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="82"/>
        <source>Samples</source>
        <translation>Mostras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="90"/>
        <source>Instruments</source>
        <translation>Instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="95"/>
        <source>Comment</source>
        <translation>Comentarios</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-0.12.2.tar.bz2: qmmp-plugin-pack-0.12.2/src/Input/xmp/translations/xmp_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="41"/>
        <source>XMP Plugin</source>
        <translation>Plugin XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="55"/>
        <source>Module Files</source>
        <translation>Ficheiros de modulación</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>About XMP Audio Plugin</source>
        <translation>Acerca do plugin XMP Audio</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="113"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Plugin Qmmp XMP Audio</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="114"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="115"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Compilando con libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Preferencias do plugin XMP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation>Factor de amplificación:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Mestura Estéreo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Tipo de interpolación:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Filtro de efecto de paso baixo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Utilizar sincronización vblank</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Emular erro do Protracker 2.x FX9</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>Veciño máis próximo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>Interpolación cúbica</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="53"/>
        <source>Volume scale</source>
        <translation>Escala do volume</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Number of patterns</source>
        <translation>Número de patróns</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Number of tracks</source>
        <translation>Número de pistas</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Tracks per pattern</source>
        <translation>Pistas por patrón</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of instruments</source>
        <translation>Número de instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Number of samples</source>
        <translation>Número de mostras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Initial speed</source>
        <translation>Velocidade inicial</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Initial BPM</source>
        <translation>BPM iniciais</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Module length in patterns</source>
        <translation>Lonxitude do módulo en patróns</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="80"/>
        <source>Samples</source>
        <translation>Mostras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="88"/>
        <source>Instruments</source>
        <translation>Instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="93"/>
        <source>Comment</source>
        <translation>Comentarios</translation>
    </message>
</context>
</TS>
